<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<!-- Include a library where global variables are set -->
	<xsl:include href="globalVariables.xsl"/>


	<xsl:template match="filelist">

		<xsl:result-document href="{$outputPath}\DDI.txt" method="text">
		<xsl:call-template name="getHeaders">
			<xsl:with-param name="headerPath" select="document($TOCMasterDocPath)/CatapultToc/TocEntry[position()=1]/@Link"/>
		</xsl:call-template>


		<xsl:for-each select="document($TOCMasterDocPath)/CatapultToc/TocEntry">
			<xsl:call-template name="getRows"><xsl:with-param name="docName" select="@Link"/></xsl:call-template>
		</xsl:for-each>	

		</xsl:result-document>

	</xsl:template>


<!-- Pulls headers from first table. This is first row of txt and defines variable names used by Photoshop -->
	<xsl:template name="getHeaders">
		<xsl:param name="headerPath"/>
		<xsl:variable name="fullPath"><xsl:value-of select="$outputPath"/><xsl:value-of select="$headerPath"/></xsl:variable>
		<xsl:for-each select="document($fullPath)/html/body/table/thead/tr/th">
			<xsl:value-of select="."/><xsl:choose><xsl:when test="position() = last()"><xsl:text disable-output-escaping="yes">&#10;</xsl:text></xsl:when><xsl:otherwise><xsl:text disable-output-escaping="yes">&#x9;</xsl:text></xsl:otherwise></xsl:choose>
		</xsl:for-each>	
	</xsl:template>


	<xsl:template name="getRows">
		<xsl:param name="docName"/>
		<xsl:variable name="fullPath"><xsl:value-of select="$outputPath"/><xsl:value-of select="$docName"/></xsl:variable>
		<xsl:apply-templates select="document($fullPath)/html/body/table/tbody/tr/td"><xsl:with-param name="position" select="position()"/></xsl:apply-templates>
		
	</xsl:template>





<!-- Pulling data from each row, column by column to populate the txt file. Counter looks at preceding tr/td and adds 1 so we dont start at zero -->
<!-- Place a tab character unless this is the last td in the row, then place a return character -->
	<xsl:template match="td[position() = 1]">
		<xsl:param name="position"/>
<xsl:value-of select="$position"/><!--<xsl:value-of select="count(preceding::tr/td[position() = 1])+1"/>--><xsl:choose><xsl:when test="position() = last()"><xsl:text disable-output-escaping="yes">&#10;</xsl:text></xsl:when><xsl:otherwise><xsl:text disable-output-escaping="yes">&#x9;</xsl:text></xsl:otherwise></xsl:choose>
	</xsl:template>

<!-- Generate full path to image sources -->
<!-- Place a tab character unless this is the last td in the row, then place a return character -->
	<xsl:template match="td[position() = 2]">
		<xsl:value-of select="$outputPath"/><xsl:apply-templates/><xsl:choose><xsl:when test="position() = last()"><xsl:text disable-output-escaping="yes">&#10;</xsl:text></xsl:when><xsl:otherwise><xsl:text disable-output-escaping="yes">&#x9;</xsl:text></xsl:otherwise></xsl:choose>
	</xsl:template>


	<xsl:template match="img">Content\<xsl:value-of select="translate(@src,'/','\')"/></xsl:template>

<!-- Dump these nodes -->
	<xsl:template match="h1"/>
	<xsl:template match="head"/>
	<xsl:template match="thead"/>
	<xsl:template match="p"/>

</xsl:stylesheet>
