<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<!-- Set output style. XML with no indentations -->
	<xsl:output method="text" indent="no" omit-xml-declaration="yes"/>

<!-- Include a library where global variables are set -->
	<xsl:include href="globalVariables.xsl"/>



	<xsl:template match="filelist">

		<xsl:result-document href="{$outputPath}\DDI.txt" method="text">
		<xsl:call-template name="getHeaders">
			<xsl:with-param name="headerPath" select="document($TOCMasterDocPath)/CatapultToc/TocEntry[position()=1]/@Link"/>
		</xsl:call-template>


		<xsl:for-each select="document($TOCMasterDocPath)/CatapultToc/TocEntry">
			<xsl:call-template name="getRows"><xsl:with-param name="docName" select="@Link"/></xsl:call-template>
		</xsl:for-each>	

		</xsl:result-document>

	</xsl:template>


	<xsl:template name="getHeaders">
		<xsl:param name="headerPath"/>
		<xsl:variable name="fullPath"><xsl:value-of select="$outputPath"/><xsl:value-of select="$headerPath"/></xsl:variable>
		<xsl:for-each select="document($fullPath)/html/body/table/thead/tr/th">
			<xsl:value-of select="."/><xsl:choose><xsl:when test="position() = last()"><xsl:text disable-output-escaping="yes">&#10;</xsl:text></xsl:when><xsl:otherwise><xsl:text disable-output-escaping="yes">&#x9;</xsl:text></xsl:otherwise></xsl:choose>
		</xsl:for-each>	
	</xsl:template>


	<xsl:template name="getRows">
		<xsl:param name="docName"/>
		<xsl:variable name="fullPath"><xsl:value-of select="$outputPath"/><xsl:value-of select="$docName"/></xsl:variable>
		<xsl:apply-templates select="document($fullPath)/html/body/table/tbody/tr"/>	
	</xsl:template>

	<xsl:template match="tr">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="td">
		<xsl:variable name="position"><xsl:choose><xsl:when test="position() = last()">T</xsl:when><xsl:otherwise>F</xsl:otherwise></xsl:choose></xsl:variable>
		<xsl:apply-templates/><xsl:choose><xsl:when test="$position = 'T'"><xsl:text disable-output-escaping="yes">&#10;</xsl:text></xsl:when><xsl:otherwise><xsl:text disable-output-escaping="yes">&#x9;</xsl:text></xsl:otherwise></xsl:choose>
	</xsl:template>

	<xsl:template match="img"><xsl:value-of select="$outputPath"/>Content\<xsl:value-of select="translate(@src,'/','\')"/></xsl:template>

<!-- Dump these nodes -->
	<xsl:template match="h1"/>
	<xsl:template match="head"/>
	<xsl:template match="thead"/>
	<xsl:template match="p"><xsl:text disable-output-escaping="yes"> </xsl:text><xsl:value-of select="."/><xsl:text disable-output-escaping="yes"> </xsl:text></xsl:template>
	<xsl:template match="b"><xsl:text disable-output-escaping="yes"> </xsl:text><xsl:value-of select="."/><xsl:text disable-output-escaping="yes"> </xsl:text></xsl:template>
	<xsl:template match="i"><xsl:text disable-output-escaping="yes"> </xsl:text><xsl:value-of select="."/><xsl:text disable-output-escaping="yes"> </xsl:text></xsl:template>
	<xsl:template match="u"><xsl:text disable-output-escaping="yes"> </xsl:text><xsl:value-of select="."/><xsl:text disable-output-escaping="yes"> </xsl:text></xsl:template>
</xsl:stylesheet>
